# WidgetCell

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**force_range** | **bool** |  | [optional] 
**h** | **int** |  | [optional] 
**i** | **str** |  | [optional] 
**id** | **str** |  | [optional] 
**w** | **int** |  | [optional] 
**widget** | [**Widget**](Widget.md) |  | [optional] 
**x** | **int** |  | [optional] 
**y** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


